@@ -6,7 +6,9 @@ import board
 import busio
 import adafruit_scd30
 
-i2c = busio.I2C(board.SCL, board.SDA)
+# SCD-30 has tempremental I2C with clock stretching, datasheet recommends
+# starting at 50KHz
+i2c = busio.I2C(board.SCL, board.SDA, frequency=50000)
 scd = adafruit_scd30.SCD30(i2c)
 
 while True:
@@ -14,9 +16,9 @@ while True:
     # the values, to ensure current readings.
     if scd.data_available:
         print("Data Available!")
-        print("CO2:", scd.CO2, "PPM")
-        print("Temperature:", scd.temperature, "degrees C")
-        print("Humidity:", scd.relative_humidity, "%%rH")
+        print("CO2: %d PPM" % scd.CO2)
+        print("Temperature: %0.2f degrees C" % scd.temperature)
+        print("Humidity: %0.2f %% rH" % scd.relative_humidity)
         print("")
         print("Waiting for new data...")
         print("")
